@@ -3,7 +3,7 @@
  * This file contains the Horde_Service_Weather_Alerts class for abstracting
  * access to weather alerts from Wunderground.
  *
- * Copyright 2011-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2017 Horde LLC (http://www.horde.org/)
  *
  * @author   Michael J Rubinsky <mrubinsk@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -49,15 +49,13 @@
                     $expires = null;
                 }
             }
+            $description = trim($alert->description);
+            $meteo_name = trim($alert->wtype_meteo_name);
             $alert = array(
                 'type' => empty($this->_typeMap[$alert->type])
                     ? ''
                     : $this->_typeMap[$alert->type],
-                'desc' => empty(trim($alert->description))
-                    ? (empty(trim($alert->wtype_meteo_name))
-                       ? ''
-                       : trim($alert->wtype_meteo_name))
-                    : trim($alert->description),
+                'desc' => $description ?: ($meteo_name ?: ''),
                 // Euro only returns this, not epoch, but it's in UTC.
                 'date_text' => $alert->date,
                 'date' => $date,
